package com.ruoyi.warehouse.check.mapper;

import java.util.List;

import com.ruoyi.common.core.domain.entity.TWarehouse;
import com.ruoyi.warehouse.check.domain.TWarehouseCheck;

/**
 * 巡检checkMapper接口
 * 
 * @author dongyongwei
 * @date 2021-07-21
 */
public interface TWarehouseCheckMapper 
{
    /**
     * 查询巡检check
     * 
     * @param fId 巡检checkID
     * @return 巡检check
     */
    public TWarehouseCheck selectTWarehouseCheckById(Long fId);

    /**
     * 查询巡检check列表
     * 
     * @param tWarehouseCheck 巡检check
     * @return 巡检check集合
     */
    public List<TWarehouseCheck> selectTWarehouseCheckList(TWarehouseCheck tWarehouseCheck);

    /**
     * 新增巡检check
     * 
     * @param tWarehouseCheck 巡检check
     * @return 结果
     */
    public int insertTWarehouseCheck(TWarehouseCheck tWarehouseCheck);

    /**
     * 修改巡检check
     * 
     * @param tWarehouseCheck 巡检check
     * @return 结果
     */
    public int updateTWarehouseCheck(TWarehouseCheck tWarehouseCheck);

    /**
     * 删除巡检check
     * 
     * @param fId 巡检checkID
     * @return 结果
     */
    public int deleteTWarehouseCheckById(Long fId);

    /**
     * 批量删除巡检check
     * 
     * @param fIds 需要删除的数据ID
     * @return 结果
     */
    public int deleteTWarehouseCheckByIds(Long[] fIds);

    /**
     * 获取主表内仓库清单
     */
    List<TWarehouse> selectTWarehouseListInCheck();
}
